@@ -6,6 +6,7 @@ from .types import Primitive, ModelDict
 
 if TYPE_CHECKING:
     from .driver import DbDriver
+    from .serializer import Serializer
 
 _KT = TypeVar('_KT')
 
@@ -64,6 +65,15 @@ class Key(Generic[_KT]):
     def delete(self):
         return Model.delete_by_key(self._key)
 
+    def save(self, data: ModelDict):
+        return Model.save_by_key(self._key, data)
+
+    def read(self):
+        return Model.read_dict(self._key)
+
+    def read_from_serializer(self, serializer: 'Serializer'):
+        return Model.read_dict_from_serializer(self._key, serializer)
+
     def __repr__(self):
         return f'Key({self._key})'
 
@@ -191,10 +201,24 @@ class Model(Generic[_KT]):
         Model.__db_drivers = {d.model_name: d for d in db_drivers}
 
     @classmethod
-    def load(cls, key: str) -> Optional[_KT]:
+    def read_dict(cls, key: str) -> ModelDict:
         model_name = key.split(':')[0]
         db_driver = Model.__db_drivers[model_name]
         data = db_driver.load_dict(key)
+
+        return data
+
+    @classmethod
+    def read_dict_from_serializer(cls, key, serializer: 'Serializer'):
+        model_name = key.split(':')[0]
+        db_driver = Model.__db_drivers[model_name]
+        data = db_driver.load_dict_from_serializer(key, serializer)
+
+        return data
+
+    @classmethod
+    def load(cls, key: str) -> Optional[_KT]:
+        data = cls.read_dict(key)
         if data is None:
             return None
         return Model.from_dict(key, data)
@@ -205,6 +229,12 @@ class Model(Generic[_KT]):
         db_driver = Model.__db_drivers[model_name]
         db_driver.delete(key)
 
+    @staticmethod
+    def save_by_key(key: str, data: ModelDict):
+        model_name = key.split(':')[0]
+        db_driver = Model.__db_drivers[model_name]
+        db_driver.save_dict(key, data)
+
     def to_dict(self) -> ModelDict:
         values = {}
         for k, v in self._values.items():
